@@ -1,32 +1,28 @@
-import re
-import requests
 import json
-from os.path import basename
+import re
+from email.mime.application import MIMEApplication
+from email.mime.multipart import MIMEMultipart
+from email.mime.text import MIMEText
+from typing import Optional
 from smtplib import SMTP, SMTP_SSL
+import requests
+from django.conf import settings
 from django.db import models
 from django.template import Template, Context
-from django.conf import settings
 from django.utils.html import format_html
 from django.utils.module_loading import import_string
-
-from email.mime.multipart import MIMEMultipart
-from email.mime.application import MIMEApplication
-from email.mime.text import MIMEText
-
+from django.utils.safestring import mark_safe
+from django.utils.timezone import now
 from viberbot import Api, BotConfiguration
 from viberbot.api.messages import TextMessage
-
-from .fcm import NotifyDevice
-
-from .choices import TYPE, STATE
 from .category import NotifyCategory
+from .choices import TYPE, STATE
 from .config import NotifyConfig
-from .template import NotifyTemplate
+from .fcm import NotifyDevice
 from .file import NotifyFile
 from .log import NotifyErrorLog
 from .smtp import SMTPAccount
-from django.utils.timezone import now
-from django.utils.safestring import mark_safe
+from .template import NotifyTemplate
 from ..mixins import UserNotifyMixin
 
 
@@ -66,6 +62,9 @@ class Notify(UserNotifyMixin):
     send_at = models.DateTimeField(blank=True, null=True, verbose_name='Время начала отправки')
     sent_at = models.DateTimeField(blank=True, null=True, verbose_name='Дата отправки')
 
+    def __str__(self):
+        return self.subject
+
     def get_sender(self):
         pass
 
@@ -75,6 +74,8 @@ class Notify(UserNotifyMixin):
             self.phone = self.user.phone
             self.telegram_chat_id = self.user.telegram_chat_id
             self.viber_chat_id = self.user.viber_chat_id
+        elif self.email:
+            self.email = self.email
 
         if self.phone is not None:
             self.phone = re.sub("[^0-9]", "", self.phone)
@@ -93,19 +94,10 @@ class Notify(UserNotifyMixin):
         self.save()
 
     def send_email(self):
-        config = NotifyConfig.get_solo()
+        account = self._get_valid_smtp_account()
 
-        if not config.is_email_enabled:
-            self.state = STATE.DISABLED
-            return
-
-        category = self.category
-        account = SMTPAccount.get_free_smtp()
-        self.sender_email = account.sender
-        if account is None or not account.is_active:
-            return None
         try:
-            body = self._render_body(account.sender, category.template)
+            body = self._render_body(account.sender, self.category.template)
             server = SMTP_SSL(account.host, account.port) if account.is_use_ssl else SMTP(account.host, account.port)
             server.ehlo()
             if account.is_use_tls:
@@ -201,9 +193,12 @@ class Notify(UserNotifyMixin):
     @staticmethod
     def send(event, context, user=None, email=None, phone=None, files=None, data_json=None, notify_templates=None,
              viber_chat_id=None):
-
         from user.models import User
 
+        if user:
+            email = user.email if not email else email
+            phone = user.phone if not phone else phone
+
         user_want_message_check = None
         if hasattr(settings, 'NOTIFY_USER_WANT_MESSAGE_CHECK') and settings.NOTIFY_USER_WANT_MESSAGE_CHECK is not None:
             user_want_message_check = import_string(settings.NOTIFY_USER_WANT_MESSAGE_CHECK)
@@ -225,7 +220,6 @@ class Notify(UserNotifyMixin):
             file_instances.append(instance)
 
         notification_count = 0
-
         for template in templates:
             # Формируем список основных и дополнительных получателей письма
             # Первого получателя заполняем из шаблона, его данные могут быть пустыми - чтобы можно было через
@@ -257,6 +251,13 @@ class Notify(UserNotifyMixin):
                             'phone': participant.phone,
                             'viber_chat_id': participant.viber_chat_id,
                         })
+                    elif participant.email is not None:
+                        recievers.append({
+                            'user': participant.user,
+                            'email': participant.email,
+                            'phone': participant.phone,
+                            'viber_chat_id': participant.viber_chat_id,
+                        })
 
                 # Если в списке отмечены группы
                 if user_list.user_groups and not user_list.mail_to_all:
@@ -286,7 +287,6 @@ class Notify(UserNotifyMixin):
                                 'viber_chat_id': user.viber_chat_id,
                             }
                         )
-
             for reciever in recievers:
                 template_user = reciever['user']
                 template_email = reciever['email']
@@ -306,7 +306,7 @@ class Notify(UserNotifyMixin):
                         template_viber_chat_id = user.viber_chat_id
                 # Проверка, хочет ли получить сообщение
                 if user_want_message_check is not None and not \
-                    user_want_message_check(event, template.type, template_user): # noqa
+                        user_want_message_check(event, template.type, template_user):  # noqa
                     continue
 
                 local_context = context.copy()
@@ -329,15 +329,14 @@ class Notify(UserNotifyMixin):
                     html=template.render_html(local_context),
                     user=template_user,
                     email=template_email,
-                    phone=template_phone,
-                    viber_chat_id=template_viber_chat_id,
+                    phone=template_phone if template_phone is not None else "",
+                    viber_chat_id=template_viber_chat_id if template_viber_chat_id is not None else "",
                     type=template.type,
                     event=template.event,
                     category=template.category,
                     data_json=data_json,
                     send_at=template.send_at,
                 )
-
                 file_instance = instance.files
                 for f in file_instances:
                     file_instance.add(f)
@@ -388,9 +387,6 @@ class Notify(UserNotifyMixin):
 
     get_format_state.short_description = 'Статус'
 
-    def __str__(self):
-        return self.subject
-
     def to_log(self, error_text):
         log = NotifyErrorLog(notify=self, error=error_text)
         log.save()
@@ -430,6 +426,19 @@ class Notify(UserNotifyMixin):
             self.state = STATE.REJECTED
             self.to_log(str(e))
 
+    def _get_valid_smtp_account(self) -> Optional[SMTPAccount]:
+        config = NotifyConfig.get_solo()
+        if not config.is_email_enabled:
+            self.state = STATE.DISABLED
+            return
+
+        account = SMTPAccount.get_free_smtp()
+        self.sender_email = account.sender
+        if account is None or not account.is_active:
+            return
+
+        return account
+
     class Meta:
         verbose_name = 'Уведомление'
         verbose_name_plural = 'Уведомления'
